@@ -23,7 +23,7 @@ names.rd_file <- function(x) {
 #' @export
 format.rd_file <- function(x, ...) {
   tags <- as.list(x[[1]])
-  order <- c("srcref", "docType", "encoding", "name", "alias", "title",
+  order <- c("backref", "docType", "encoding", "name", "alias", "title",
     "format", "source", "usage", "param", "value", "description",
     "details", "minidesc", "field", "slot", "rcmethods", "note",
     "section", "examples", "author", "references", "seealso",
